==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/awscdk/AwsCdkDeps.java <==
package io.github.cdklabs.projen.awscdk;

/**
 * (experimental) Manages dependencies on the AWS CDK.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.492Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.awscdk.AwsCdkDeps")
public class AwsCdkDeps extends io.github.cdklabs.projen.Component {

    protected AwsCdkDeps(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected AwsCdkDeps(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public AwsCdkDeps(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.awscdk.AwsCdkDepsOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * (experimental) Adds dependencies to AWS CDK modules.
     * <p>
     * The type of dependency is determined by the <code>dependencyType</code> option.
     * <p>
     * This method is not supported in CDK v2. Use <code>project.addPeerDeps()</code> or
     * <code>project.addDeps()</code> as appropriate.
     * <p>
     * @param deps names of cdk modules (e.g. `@aws-cdk/aws-lambda`). This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addV1Dependencies(final @org.jetbrains.annotations.NotNull java.lang.String... deps) {
        software.amazon.jsii.Kernel.call(this, "addV1Dependencies", software.amazon.jsii.NativeType.VOID, java.util.Arrays.<Object>stream(deps).toArray(Object[]::new));
    }

    /**
     * (experimental) Adds AWS CDK modules as dev dependencies.
     * <p>
     * This method is not supported in CDK v2. Use <code>project.addPeerDeps()</code> or
     * <code>project.addDeps()</code> as appropriate.
     * <p>
     * @param deps names of cdk modules (e.g. `@aws-cdk/aws-lambda`). This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addV1DevDependencies(final @org.jetbrains.annotations.NotNull java.lang.String... deps) {
        software.amazon.jsii.Kernel.call(this, "addV1DevDependencies", software.amazon.jsii.NativeType.VOID, java.util.Arrays.<Object>stream(deps).toArray(Object[]::new));
    }

    /**
     * (deprecated) Whether CDK dependencies are added as normal dependencies (and peer dependencies).
     * <p>
     * @deprecated Not used for CDK 2.x
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public @org.jetbrains.annotations.NotNull java.lang.Boolean getCdkDependenciesAsDeps() {
        return software.amazon.jsii.Kernel.get(this, "cdkDependenciesAsDeps", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
    }

    /**
     * (experimental) The major version of the AWS CDK (e.g. 1, 2, ...).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.Number getCdkMajorVersion() {
        return software.amazon.jsii.Kernel.get(this, "cdkMajorVersion", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
    }

    /**
     * (experimental) The minimum version of the AWS CDK (e.g. `2.0.0`).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getCdkMinimumVersion() {
        return software.amazon.jsii.Kernel.get(this, "cdkMinimumVersion", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) The dependency requirement for AWS CDK (e.g. `^2.0.0`).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getCdkVersion() {
        return software.amazon.jsii.Kernel.get(this, "cdkVersion", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.awscdk.AwsCdkDeps}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.awscdk.AwsCdkDeps> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.Project project;
        private final io.github.cdklabs.projen.awscdk.AwsCdkDepsOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project) {
            this.project = project;
            this.options = new io.github.cdklabs.projen.awscdk.AwsCdkDepsOptions.Builder();
        }

        /**
         * (experimental) Minimum version of the AWS CDK to depend on.
         * <p>
         * Default: "2.1.0"
         * <p>
         * @return {@code this}
         * @param cdkVersion Minimum version of the AWS CDK to depend on. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder cdkVersion(final java.lang.String cdkVersion) {
            this.options.cdkVersion(cdkVersion);
            return this;
        }

        /**
         * (deprecated) Install the @aws-cdk/assert library?
         * <p>
         * Default: - will be included by default for AWS CDK >= 1.0.0 < 2.0.0
         * <p>
         * @return {@code this}
         * @deprecated The
         * @param cdkAssert Install the @aws-cdk/assert library?. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder cdkAssert(final java.lang.Boolean cdkAssert) {
            this.options.cdkAssert(cdkAssert);
            return this;
        }

        /**
         * (experimental) Install the @aws-cdk/assertions library?
         * <p>
         * Only needed for CDK 1.x. If using CDK 2.x then
         * assertions is already included in 'aws-cdk-lib'
         * <p>
         * Default: - will be included by default for AWS CDK >= 1.111.0 < 2.0.0
         * <p>
         * @return {@code this}
         * @param cdkAssertions Install the @aws-cdk/assertions library?. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder cdkAssertions(final java.lang.Boolean cdkAssertions) {
            this.options.cdkAssertions(cdkAssertions);
            return this;
        }

        /**
         * (deprecated) Which AWS CDK modules (those that start with "@aws-cdk/") does this library require when consumed?
         * <p>
         * @return {@code this}
         * @deprecated For CDK 2.x use 'peerDeps' instead
         * @param cdkDependencies Which AWS CDK modules (those that start with "@aws-cdk/") does this library require when consumed?. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder cdkDependencies(final java.util.List<java.lang.String> cdkDependencies) {
            this.options.cdkDependencies(cdkDependencies);
            return this;
        }

        /**
         * (deprecated) If this is enabled (default), all modules declared in `cdkDependencies` will be also added as normal `dependencies` (as well as `peerDependencies`).
         * <p>
         * This is to ensure that downstream consumers actually have your CDK dependencies installed
         * when using npm &lt; 7 or yarn, where peer dependencies are not automatically installed.
         * If this is disabled, <code>cdkDependencies</code> will be added to <code>devDependencies</code> to ensure
         * they are present during development.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @deprecated Not supported in CDK v2.
         * @param cdkDependenciesAsDeps If this is enabled (default), all modules declared in `cdkDependencies` will be also added as normal `dependencies` (as well as `peerDependencies`). This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder cdkDependenciesAsDeps(final java.lang.Boolean cdkDependenciesAsDeps) {
            this.options.cdkDependenciesAsDeps(cdkDependenciesAsDeps);
            return this;
        }

        /**
         * (deprecated) AWS CDK modules required for testing.
         * <p>
         * @return {@code this}
         * @deprecated For CDK 2.x use 'devDeps' instead
         * @param cdkTestDependencies AWS CDK modules required for testing. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder cdkTestDependencies(final java.util.List<java.lang.String> cdkTestDependencies) {
            this.options.cdkTestDependencies(cdkTestDependencies);
            return this;
        }

        /**
         * (experimental) Use pinned version instead of caret version for CDK.
         * <p>
         * You can use this to prevent yarn to mix versions for your CDK dependencies and to prevent auto-updates.
         * If you use experimental features this will let you define the moment you include breaking changes.
         * <p>
         * @return {@code this}
         * @param cdkVersionPinning Use pinned version instead of caret version for CDK. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder cdkVersionPinning(final java.lang.Boolean cdkVersionPinning) {
            this.options.cdkVersionPinning(cdkVersionPinning);
            return this;
        }

        /**
         * (experimental) Minimum version of the `constructs` library to depend on.
         * <p>
         * Default: - for CDK 1.x the default is "3.2.27", for CDK 2.x the default is
         * "10.0.5".
         * <p>
         * @return {@code this}
         * @param constructsVersion Minimum version of the `constructs` library to depend on. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder constructsVersion(final java.lang.String constructsVersion) {
            this.options.constructsVersion(constructsVersion);
            return this;
        }

        /**
         * (experimental) The type of dependency to use for runtime AWS CDK and `constructs` modules.
         * <p>
         * For libraries, use peer dependencies and for apps use runtime dependencies.
         * <p>
         * @return {@code this}
         * @param dependencyType The type of dependency to use for runtime AWS CDK and `constructs` modules. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder dependencyType(final io.github.cdklabs.projen.DependencyType dependencyType) {
            this.options.dependencyType(dependencyType);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.awscdk.AwsCdkDeps}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.awscdk.AwsCdkDeps build() {
            return new io.github.cdklabs.projen.awscdk.AwsCdkDeps(
                this.project,
                this.options.build()
            );
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/awscdk/AwsCdkDeps.java <==
package io.github.cdklabs.projen.awscdk;

/**
 * (experimental) Manages dependencies on the AWS CDK.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.208Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.awscdk.AwsCdkDeps")
public abstract class AwsCdkDeps extends io.github.cdklabs.projen.Component {

    protected AwsCdkDeps(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected AwsCdkDeps(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    protected AwsCdkDeps(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.awscdk.AwsCdkDepsOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * (experimental) Adds dependencies to AWS CDK modules.
     * <p>
     * The type of dependency is determined by the <code>dependencyType</code> option.
     * <p>
     * This method is not supported in CDK v2. Use <code>project.addPeerDeps()</code> or
     * <code>project.addDeps()</code> as appropriate.
     * <p>
     * @param deps names of cdk modules (e.g. <code>&#64;aws-cdk/aws-lambda</code>). This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addV1Dependencies(final @org.jetbrains.annotations.NotNull java.lang.String... deps) {
        software.amazon.jsii.Kernel.call(this, "addV1Dependencies", software.amazon.jsii.NativeType.VOID, java.util.Arrays.<Object>stream(deps).toArray(Object[]::new));
    }

    /**
     * (experimental) Adds AWS CDK modules as dev dependencies.
     * <p>
     * This method is not supported in CDK v2. Use <code>project.addPeerDeps()</code> or
     * <code>project.addDeps()</code> as appropriate.
     * <p>
     * @param deps fully qualified names of cdk modules (e.g. <code>&#64;aws-cdk/aws-lambda</code>). This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addV1DevDependencies(final @org.jetbrains.annotations.NotNull java.lang.String... deps) {
        software.amazon.jsii.Kernel.call(this, "addV1DevDependencies", software.amazon.jsii.NativeType.VOID, java.util.Arrays.<Object>stream(deps).toArray(Object[]::new));
    }

    /**
     * (experimental) Return a configuration object with information about package naming in various languages.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    protected abstract @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.awscdk.AwsCdkPackageNames packageNames();

    /**
     * (experimental) Called before synthesis.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @Override
    public void preSynthesize() {
        software.amazon.jsii.Kernel.call(this, "preSynthesize", software.amazon.jsii.NativeType.VOID);
    }

    /**
     * (deprecated) Whether CDK dependencies are added as normal dependencies (and peer dependencies).
     * <p>
     * @deprecated Not used for CDK 2.x
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public @org.jetbrains.annotations.NotNull java.lang.Boolean getCdkDependenciesAsDeps() {
        return software.amazon.jsii.Kernel.get(this, "cdkDependenciesAsDeps", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
    }

    /**
     * (experimental) The major version of the AWS CDK (e.g. 1, 2, ...).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.Number getCdkMajorVersion() {
        return software.amazon.jsii.Kernel.get(this, "cdkMajorVersion", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
    }

    /**
     * (experimental) The minimum version of the AWS CDK (e.g. <code>2.0.0</code>).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getCdkMinimumVersion() {
        return software.amazon.jsii.Kernel.get(this, "cdkMinimumVersion", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) The dependency requirement for AWS CDK (e.g. <code>^2.0.0</code>).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getCdkVersion() {
        return software.amazon.jsii.Kernel.get(this, "cdkVersion", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    @software.amazon.jsii.Internal
    private static final class Jsii$Proxy extends io.github.cdklabs.projen.awscdk.AwsCdkDeps implements software.constructs.IConstruct.Jsii$Default {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * (experimental) Return a configuration object with information about package naming in various languages.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        protected final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.awscdk.AwsCdkPackageNames packageNames() {
            return software.amazon.jsii.Kernel.call(this, "packageNames", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.awscdk.AwsCdkPackageNames.class));
        }
    }
}
